#!/bin/sh

# This script executes the viv_samples,fsl-samples/g2d_samples from imx-gpu-viv and imx-gpu-g2d packages provided by NXP to test and confirm the 2D,3D and accelerated graphics demos.

if [ $(pidof weston) ];then
    export XDG_RUNTIME_DIR=/run/user/root
    ver=$(weston --version | awk '{print $2}')
    if [[ ${ver:0:2} -ge 11 ]];then
       export WAYLAND_DISPLAY=wayland-1
    fi
fi

TEST_NAME=$1

usage(){
echo "Applicable TEST : VG,2D,3D"
echo "Syntax : ./test_graphics_gpu_imx.sh {TEST}"
echo "Example: ./test_graphics_qt5.sh VG"
}

echo "This test case requires an engineer to manually observe the output on screen."

run_vgtest(){
echo "-----Running VG Test-----"
if [ -f /opt/viv_samples/tiger/tiger ]; then
	/opt/viv_samples/tiger/tiger
	echo ""
else
	echo "Open VG test binaries are not present. Kindly check the build"
	echo "Open VG test: FAIL"
	exit 1
fi
}

run_2dtest(){
echo "-----Running Graphics 2D Test-----"
if [ -f /opt/fsl-samples/g2d/g2d_test ]; then
	/opt/fsl-samples/g2d/g2d_test
	echo ""
elif [ -f /opt/g2d_samples/g2d_test ]; then
	/opt/g2d_samples/g2d_test
	echo ""
else
	echo "Graphics 2D test binaries are not present. Kindly check the build."
	echo "Graphics 2D test: FAIL"
	exit 1
fi
}

run_3dtest(){
echo "-----Running Graphics 3D Test-----"
if [ -f /opt/viv_samples/vdk/cover_flow ]; then
	/opt/viv_samples/vdk/cover_flow &
        sleep 2
        killall cover_flow
else
	echo "Cover Flow test binaries are not present. Kindly check the build."
	echo "Cover Flow test: FAIL"
	exit 1
fi
}

main(){

if [ $TEST_NAME == "VG" ];then
	run_vgtest
elif [ $TEST_NAME == "2D" ];then
	run_2dtest
elif [ $TEST_NAME == "3D" ];then
	run_3dtest
else
	echo "Invalid Test"
	usage
	exit 1
fi
}
main
