#!/bin/sh

XDG_RUNTIME_DIR=/run/user/root
export XDG_RUNTIME_DIR=$XDG_RUNTIME_DIR
ver=$(weston --version | awk '{print $2}')
if [[ ${ver:0:2} -ge 11 ]];then
    export WAYLAND_DISPLAY=wayland-1
fi

PLATFORM_PLUGIN=$1

usage(){
echo "Applicable Plugin : eglfs,linuxfb,wayland,wayland-egl,xcb"
echo "Syntax : ./test_graphics_qt5.sh {Plugin}"
echo "Example: ./test_graphics_qt5.sh wayland"
}

if [ -z $PLATFORM_PLUGIN ]; then
	echo "Provide Plugin to run qt5 application"
	usage
	exit 1
fi 

run_eglfs(){
PID=$(pidof weston)
kill $PID
sleep 2

echo "-----Running Openglwindow-----"
/usr/share/examples/gui/openglwindow/openglwindow -platform $PLATFORM_PLUGIN &
PID=$!
sleep 5
kill $PID
sleep 2

echo "-----Running Hellowindow-----"
/usr/share/examples/opengl/hellowindow/hellowindow -platform $PLATFORM_PLUGIN &
PID=$!
sleep 5
kill $PID
sleep 2

echo "-----Running Hellogl2-----"
/usr/share/examples/opengl/hellogl2/hellogl2 -platform $PLATFORM_PLUGIN &
PID=$!
sleep 5
kill $PID
sleep 2
}

run_linuxfb(){
PID=$(pidof weston)
kill $PID
sleep 2

echo "-----Running Analogclock----- "
/usr/share/examples/gui/analogclock/analogclock -platform $PLATFORM_PLUGIN &
PID=$!
sleep 5
kill $PID
}

run_wayland(){
echo "-----Running Analogclock-----"
/usr/share/examples/gui/analogclock/analogclock -platform $PLATFORM_PLUGIN &
PID=$!
sleep 5
kill $PID

echo "-----Running Openglwindow-----"
/usr/share/examples/gui/openglwindow/openglwindow -platform $PLATFORM_PLUGIN &
PID=$!
sleep 5
kill $PID

echo "-----Running Hellowindow-----"
/usr/share/examples/opengl/hellowindow/hellowindow -platform $PLATFORM_PLUGIN &
PID=$!
sleep 5
kill $PID

echo "-----Running Hellogl2-----"
/usr/share/examples/opengl/hellogl2/hellogl2 -platform $PLATFORM_PLUGIN &
PID=$!
sleep 5
kill $PID
}

run_wayland_egl(){
echo "-----Running Openglwindow-----"
/usr/share/examples/gui/openglwindow/openglwindow -platform $PLATFORM_PLUGIN &
PID=$!
sleep 5
kill $PID

echo "-----Running Hellowindow-----"
/usr/share/examples/opengl/hellowindow/hellowindow -platform $PLATFORM_PLUGIN &
PID=$!
sleep 5
kill $PID

echo "-----Running Hellogl2-----"
/usr/share/examples/opengl/hellogl2/hellogl2 -platform $PLATFORM_PLUGIN &
PID=$!
sleep 5
kill $PID
}

run_xcb(){
export DISPLAY=:0
echo "-----Running Analogclock-----"
/usr/share/examples/gui/analogclock/analogclock -platform $PLATFORM_PLUGIN &
PID=$!
sleep 5
kill $PID
}

main(){
if [ $PLATFORM_PLUGIN == "eglfs" ];then
	echo "-----QT5 application with eglfs plugin-----"
	run_eglfs
elif [ $PLATFORM_PLUGIN == "linuxfb" ];then
	echo "-----QT5 application with linuxfb plugin-----"
	run_linuxfb
elif [ $PLATFORM_PLUGIN == "wayland" ];then
	echo "-----QT5 application with wayland plugin-----"
	run_wayland
elif [ $PLATFORM_PLUGIN == "wayland-egl" ];then
	echo "-----QT5 application with wayland-egl plugin-----"
	run_wayland_egl
elif [ $PLATFORM_PLUGIN == "xcb" ];then
	echo "-----QT5 application with xcb plugin-----"
	run_xcb
else
	echo "Invalid plugin"
	usage
	exit 1
fi
}
main

