#!/bin/sh

source "@TSTPLIB@"

load_libraries ssh net/iperf

dep_check_programs iperf3 udhcpc

# This script tests ethernet functionality by ssh to the remote server and it perform the test using ping and iperf utility. It also executes udhcpc to obtain ip for currently running target.

ETHIF=eth0

trap "exit 1" TERM
TMP_PID="/tmp/pid"

check_ethernet() {
	sysfsNetDir=/sys/class/net/$ETHIF

	if [ ! -d $sysfsNetDir ]; then
		echo "Ethernet Interface $ETHIF Not Found"
		exit 1
	else
		netIfState=`cat $sysfsNetDir/operstate`
		if [ "$netIfState" = "up" ]; then
			echo "Ethernet Interface $ETHIF is Up"
			ping $IPADDR -c1 2>&1 >/dev/null
			if [ $? -ne 0 ]; then
				echo "Remote machine IP address is not reachable"
				exit 1
			fi
		elif [ "$netIfState" = "down" ]; then
			echo -e "Ethernet Interface $ETHIF is Down\nRunning udhcpc ..."
			udhcpc -i $ETHIF -t 10 -n
			if [ $? -ne 0 ];then
				echo "udhcpc failed to obtain an IP address"
				echo "Make sure working Ethernet cable is connected to the target"
				exit 1
			else
				echo "udhcpc successfully executed"
				ping $IPADDR -c1 2>&1 >/dev/null
				if [ $? -ne 0 ]; then
					echo "Remote machine IP address is not reachable"
					exit 1
				fi
			fi
		fi
	fi
	
	[ -z "$PINGLOC" ] && skipPingTest=1 && echo "Skipping ping test"
	
	if [ -z "$skipPingTest" ] && ! ping $PINGLOC -c 5; then
		echo "Could not ping $PINGLOC"
		exit 1
	fi
}

main(){
	check_ethernet
	check_connection
	[ "$IPERF" = "Y" ] || return 0

	echo "PREREQUISITE: Kindly make sure iperf3 is installed at remote machine as well."
	sleep 2

	Run_iperf3_on_Remote && Run_iperf3_on_DUT || \
		error "iPerf3 test was not done. If needed pass the argument 'Y' for IPERF in the conf."
} 

opt_parse_L() { PINGLOC=$OPTARG; }
opt_usage_L() { echo "Ping URL (e.g: www.google.com)"; }
opt_parse_I() { ETHIF=$OPTARG; }
opt_usage_I() { echo "Target machine ethernet interface (e.g: eth0)"; }
opt_parse_A() { IPADDR=$OPTARG;PINGLOC=$IPADDR; }
opt_usage_A() { echo "Remote machine IP address"; }
opt_parse_U() { USER=$OPTARG; }
opt_usage_U() { echo "Remote machine user name"; }
opt_parse_P() { PASSWD=$OPTARG; }
opt_usage_P() { echo "Remote machine password"; }
opt_parse_E() { info "iperf testing enabled"; IPERF=Y; }
opt_usage_E() { echo "Enable iPerf3 test"; }

parse_opts "L:I:A:U:P:E:" "$@"
[ "$IPADDR" -a "$USER" ] || usage
main

